@@ -132,11 +132,17 @@ def calc_chi_sq_for_pd_by_dictionary(
     flags_pd_phase_ig = dict_pd["flags_phase_ig"] # IG_phase
 
     resolution_parameters = dict_pd["resolution_parameters"] # U, V, W, X, Y
-    asymmetry_parameters = dict_pd["asymmetry_parameters"] # p1, p2, p3, p4
+    if "asymmetry_parameters" in dict_pd_keys:
+        asymmetry_parameters = dict_pd["asymmetry_parameters"] # p1, p2, p3, p4
+        flags_asymmetry_parameters = dict_pd["flags_asymmetry_parameters"] 
+        flag_asymmetry_parameters = numpy.any(flags_asymmetry_parameters)
+        p_1, p_2, p_3, p_4 = asymmetry_parameters[0], asymmetry_parameters[1], asymmetry_parameters[2], asymmetry_parameters[3]
+
+    else:
+        p_1, p_2, p_3, p_4 = 0., 0., 0., 0.
+        flag_asymmetry_parameters = False
 
     flags_resolution_parameters = dict_pd["flags_resolution_parameters"] 
-    flags_asymmetry_parameters = dict_pd["flags_asymmetry_parameters"] 
-    flag_asymmetry_parameters = numpy.any(flags_asymmetry_parameters)
     
     if "texture_name" in dict_pd_keys:
         flag_texture = True
@@ -348,7 +354,6 @@ def calc_chi_sq_for_pd_by_dictionary(
         
         hh = resolution_parameters + p_resolution
         u, v, w, x, y = hh[0], hh[1], hh[2], hh[3], hh[4]
-        p_1, p_2, p_3, p_4 = asymmetry_parameters[0], asymmetry_parameters[1], asymmetry_parameters[2], asymmetry_parameters[3]
         
         profile_pv, dder_pv = calc_profile_pseudo_voight(ttheta_zs, ttheta_hkl, u, v, w, p_ig, x, y,
             p_1, p_2, p_3, p_4, 
